@@ -1384,8 +1384,6 @@ static gboolean
 draw (GtkWidget * widget,
       cairo_t *cr, GkbdKeyboardDrawing * drawing)
 {
-	GtkAllocation allocation;
-
 	if (!drawing->xkb)
 		return FALSE;
 
@@ -1396,13 +1394,10 @@ draw (GtkWidget * widget,
         cairo_paint (cr);
 
 	if (gtk_widget_has_focus (widget)) {
-		gtk_widget_get_allocation (widget, &allocation);
-		gtk_paint_focus (gtk_widget_get_style (widget),
-				 cr,
-				 gtk_widget_get_state (widget),
-				 widget, "keyboard-drawing",
-				 0, 0, allocation.width,
-				 allocation.height);
+                gtk_render_focus (gtk_widget_get_style_context (widget),
+                                  cr, 0, 0,
+                                  gtk_widget_get_allocated_width (widget),
+                                  gtk_widget_get_allocated_height (widget));
 	}
 
 	return FALSE;
@@ -2384,7 +2379,7 @@ gkbd_keyboard_drawing_draw_page (GtkPrintOperation * operation,
 	gdouble dpi_y = gtk_print_context_get_dpi_y (context);
 	gchar *header;
 
-	gtk_print_operation_set_unit (operation, GTK_PIXELS);
+	gtk_print_operation_set_unit (operation, GTK_UNIT_PIXEL);
 
 	header = g_strdup_printf
 	    (_("Keyboard layout \"%s\"\n"
